﻿
/**
 * @license Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.html or http://ckeditor.com/license
 */

/**
 * This file was added automatically by CKEditor builder.
 * You may re-use it at any time at http://ckeditor.com/builder to build CKEditor again.
 * 
 * NOTE: 
 *    This file is not used by CKEditor, you may remove it.
 *    Changing this file will not change your CKEditor configuration.
 */

var CKBUILDER_CONFIG = {
	skin: 'moono',
	preset: 'basic',
	ignore: [
		'dev',
		'.gitignore',
		'.gitattributes',
		'README.md',
		'.mailmap'
	],
	plugins : {
		'about' : 1,
		'basicstyles' : 1,
		'clipboard' : 1,
		'toolbar' : 1,
		'enterkey' : 1,
		'entities' : 1,
		'floatingspace' : 1,
		'wysiwygarea' : 1,
		'link' : 1,
		'list' : 1,
		'pastetext' : 1,
		'undo' : 1,
		'dialog' : 1,
		'dialogui' : 1,
		'button' : 1,
		'fakeobjects' : 1,
		'panelbutton' : 1,
		'panel' : 1,
		'floatpanel' : 1,
		'colorbutton' : 1,
		'listblock' : 1,
		'richcombo' : 1,
		'font' : 1,
		'image' : 1,
		'menu' : 1,
		'menubutton' : 1,
		'scayt' : 1,
		'format' : 1,
		'justify' : 1,
		'wsc' : 1,
		'colordialog' : 1,
		'contextmenu' : 1,
		'blockquote' : 1,
		'indentlist' : 1,
		'table' : 1,
		'tabletools' : 1,
		'tableresize' : 1,
		'tab' : 1,
		'div' : 1
	},
	languages : {
		'ar' : 1,
		'ca' : 1,
		'cs' : 1,
		'da' : 1,
		'nl' : 1,
		'en' : 1,
		'fi' : 1,
		'fr' : 1,
		'de' : 1,
		'hu' : 1,
		'is' : 1,
		'it' : 1,
		'no' : 1,
		'nb' : 1,
		'pl' : 1,
		'pt-br' : 1,
		'ru' : 1,
		'sk' : 1,
		'es' : 1,
		'sv' : 1,
		'uk' : 1,
		'cy' : 1
	}
};